Metrics for assessing ecological indicators of biodiversity in rivers and lakes. Specifically coded to be used with TIBCO Enterprise Runtime for R (TERR).
| Package: | aquaMetrics |
| Type: | Package |
| Version: | 0.98-2 |
| Date: | 2017-03-30 |
| License: | MIT |
This package contains several functions which compute multiple ecological metrics at different Taxonomic Levels (TL) using multiple season combinations.
SPEAR (CalcSPEAR)
Species at Risk
PSI (CalcPSI)
Proportion of Sediment-sensitive Invertebrates
LIFE (CalcLIFE)
Lotic Invertebrate Index for Flow Evaluation
Riverfly's ASI (CalcASI)
Riverfly Angler's Score Index
Climate Change (CalcCC)
Climate Change. Thermal indicator.
DARLEQ (CalcDARLEQ)
Diatoms for Assessing River and Lake Ecological Quality
Taxonomic Levels are the different output options developed by RIVAPCS
to produce results at both species and family levels:
TL1 - BMWP families
TL2 - Revised BMWP (WHPT) families
TL3 - All families
TL4 - RIVPACS species
TL5 - WFD species
Season codes define different season combinations used to calculate the
indices, those are listed below:
1 = spring
2 = summer
3 = autumn
4 = spring + summer
5 = spring + autumn
6 = summer + autumn
7 = spring + summer + autumn
There is also a common routine (StandardiseRawTaxa) which should
be run prior to any calculation in order to standardise taxa counts into the
required Taxonomic Levels.
Scottish Environment Protection Agency
Maintainer: Carlos Ruiz carlos.ruiz@sepa.org.uk
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.